| Title: | Toolbox for Integrative Pathomics Analysis |
|---|---|
| Description: | Processing and analysis of pathomics, omics and other medical datasets. 'tRigon' serves as a toolbox for descriptive and statistical analysis, correlations, plotting and many other methods for exploratory analysis of high-dimensional datasets. |
| Authors: | David Hoelscher [aut, cre]
|
| Maintainer: | David Hoelscher <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.3.3 |
| Built: | 2026-05-23 07:45:14 UTC |
| Source: | https://github.com/cran/tRigon |
Run tRigon application
run_tRigon()run_tRigon()
app
David Hoelscher
if(interactive()){ run_tRigon() }if(interactive()){ run_tRigon() }